<?php
  defined('ABSPATH') or die("Please don't run this script.");
class Simple_Days_Customize {

   public static function register ( $wp_customize ) {
      //delete header textcolor control
      $wp_customize->remove_control("header_textcolor");
      $wp_customize->remove_control("background_color");

      $wp_customize->add_panel( 'simple_days_setting', array(
        'priority'    => 0,
        'title'       => esc_html__('Simple Days settings', 'simple-days'),
      ));


      $wp_customize->add_section('simple_days_layout',array(
        'title' => esc_html__('Layout', 'simple-days'),
        'panel' => 'simple_days_setting',
      ));

  // Add Settings and Controls for Layout.
  $wp_customize->add_setting( 'simple_days_sidebar_layout', array(
    'default'           => '3',
    'sanitize_callback' => 'simple_days_sanitize_radio',
    )
  );
  $wp_customize->add_control( 'simple_days_sidebar_layout', array(
    'label'    => esc_html__( 'Sidebar Layout', 'simple-days' ),
    'section'  => 'simple_days_layout',
    'type'     => 'radio',
    'choices'  => array(
      '1' => esc_html__( 'Left Sidebar', 'simple-days' ),
      '3' => esc_html__( 'Right Sidebar', 'simple-days' ),
      ),
    )
  );


  $wp_customize->add_setting('excerpt_length',array('sanitize_callback' => 'absint',));
  $wp_customize->add_control('excerpt_length',array(
    'section' => 'simple_days_layout',
    'type' => 'hidden'
  ));
  $wp_customize->selective_refresh->add_partial( 'excerpt_length', array(
         'selector' => '.post_card .summary',
  ));
  $wp_customize->add_setting( 'simple_days_excerpt_length_customize', array(
    'default' => 50,
    'sanitize_callback' => 'absint',
  ));
  $wp_customize->add_control( 'simple_days_excerpt_length_customize', array(
    'label' => esc_html__( 'Excerpt length', 'simple-days' ),
    'description' => esc_html__('default&#58;', 'simple-days').esc_html('50'),
    'section' => 'simple_days_layout',
    'type' => 'number',
    'input_attrs' => array(
    'min' => '0', 'step' => '1', 'max' => '300',),
  ));


      $wp_customize->add_setting('post_date_wrap',array('sanitize_callback' => 'absint',));
      $wp_customize->add_control('post_date_wrap',array(
        'section' => 'simple_days_layout',
        'type' => 'hidden'
      ));
      $wp_customize->selective_refresh->add_partial( 'post_date_wrap', array(
         'selector' => '.post_date_wrap',
      ));
  $wp_customize->add_setting( 'simple_days_top_date_format', array(
    'default'           => '1',
    'sanitize_callback' => 'simple_days_sanitize_radio',
    )
  );
  $wp_customize->add_control( 'simple_days_top_date_format', array(
    'label'    => esc_html__( 'post date display format', 'simple-days' ),
    'section'  => 'simple_days_layout',
    'type'     => 'radio',
    'choices'  => array(
      '1' => esc_html__( 'day-month-year', 'simple-days' ),
      '2' => esc_html__( 'month-day-year', 'simple-days' ),
    ),
  ));
  $wp_customize->add_setting( 'simple_days_top_date_wrap', array(
    'default'           => '1',
    'sanitize_callback' => 'simple_days_sanitize_radio',
    )
  );
  $wp_customize->add_control( 'simple_days_top_date_wrap', array(
    'label'    => esc_html__( 'post date display shape', 'simple-days' ),
    'description' => esc_html__('around of a line appear rounded or squared', 'simple-days'),
    'section'  => 'simple_days_layout',
    'type'     => 'radio',
    'choices'  => array(
      '1' => esc_html__( 'Circle', 'simple-days' ),
      '2' => esc_html__( 'Square', 'simple-days' ),
    ),
  ));

  $wp_customize->add_setting('back_to_top_button',array('sanitize_callback' => 'absint',));
  $wp_customize->add_control('back_to_top_button',array(
    'section' => 'simple_days_layout',
    'type' => 'hidden'
  ));
  $wp_customize->selective_refresh->add_partial( 'back_to_top_button', array(
         'selector' => '.to_top',
  ));
  $wp_customize->add_setting( 'simple_days_back_to_top_button',array(
    'default'    => true,
    'sanitize_callback' => 'sanitize_text_field',
  ));
  $wp_customize->add_control( 'simple_days_back_to_top_button',array(
    'label'   => esc_html__( 'Enable', 'simple-days'),
    'description' => esc_html__('Back to top button', 'simple-days'),
    'section' => 'simple_days_layout',
    'type' => 'checkbox',
  ));






      function simple_days_sanitize_radio( $input, $setting ){
         //input must be a slug: lowercase alphanumeric characters, dashes and underscores are allowed only
            $input = sanitize_key($input);
            //get the list of possible radio box options
            $choices = $setting->manager->get_control( $setting->id )->choices;
            //return input if valid or return default option
            return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
      }

      function simple_days_sanitize_select( $input, $setting ){
            //input must be a slug: lowercase alphanumeric characters, dashes and underscores are allowed only
            $input = sanitize_key($input);
            //get the list of possible select options
            $choices = $setting->manager->get_control( $setting->id )->choices;
            //return input if valid or return default option
            return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
      }

      function simple_days_sanitize_image_file( $file, $setting ) {
            //allowed file types
            $mimes = array(
                'jpg|jpeg|jpe' => 'assets/images/jpeg',
                'gif'          => 'assets/images/gif',
                'png'          => 'assets/images/png'
            );
            //check file type from file name
            $file_ext = wp_check_filetype( $file, $mimes );
            //if file has a valid mime type return it, otherwise return default
            return ( $file_ext['ext'] ? $file : $setting->default );
      }

    //select sanitization function
      function simple_days_sns_name_sanitize($input){
          //input must be a slug: lowercase alphanumeric characters, dashes and underscores are allowed only
          $input = sanitize_key($input);
          //get the list of possible select options
          $choices = array(
                            'none'            => '-',
                            'buffer'          => 'buffer',
                            'digg'            => 'digg',
                            'mail'            => 'Email',
                            'evernote'        => 'Evernote',
                            'facebook'        => 'Facebook',
                            'feedly'          => 'Feedly',
                            'flickr'          => 'Flickr',
                            'github'          => 'Github',
                            'googleplus'      => 'Google+',
                            'hatenabookmark'  => 'Hatena Bookmark',
                            'instagram'       => 'Instagram',
                            'line'            => 'Line',
                            'linkedin'        => 'LinkedIn',
                            'messenger'       => 'Messenger',
                            'pinterest'       => 'Pinterest',
                            'pocket'          => 'Pocket',
                            'reddit'          => 'Reddit',
                            'rss'             => 'RSS',
                            'tumblr'          => 'Tumblr',
                            'twitter'         => 'Twitter',
                            'whatsapp'        => 'WhatsApp',
                            'vimeo'           => 'Vimeo',
                            'youtube'         => 'Youtube',
                          );
          //return input if valid or return default option
          return ( array_key_exists( $input, $choices ) ? $input : '' );
      }






      $wp_customize->add_section('simple_days_single',array(
        'title' => esc_html__('Single Post','simple-days'),
        'panel' => 'simple_days_setting',
      ));



      $wp_customize->add_setting('single_thumbnail',array('sanitize_callback' => 'absint',));
      $wp_customize->add_control('single_thumbnail',array(
        'section' => 'simple_days_single',
        'type' => 'hidden'
      ));
      $wp_customize->selective_refresh->add_partial( 'single_thumbnail', array(
         'selector' => '.single_thumbnail',
      ));

      $wp_customize->add_setting( 'simple_days_single_thumbnail',array(
        'default'    => true,
        'sanitize_callback' => 'sanitize_text_field',
      ));
      $wp_customize->add_control( 'simple_days_single_thumbnail',array(
        'label'   => esc_html__( 'Display', 'simple-days'),
        'description' => esc_html__('Thumbnail', 'simple-days'),
        'section' => 'simple_days_single',
        'type' => 'checkbox',
      ));


      $wp_customize->add_setting('author_profile',array('sanitize_callback' => 'absint',));
      $wp_customize->add_control('author_profile',array(
        'section' => 'simple_days_single',
        'type' => 'hidden'
      ));
      $wp_customize->selective_refresh->add_partial( 'author_profile', array(
         'selector' => '.tabs',
      ));

      $wp_customize->add_setting( 'simple_days_single_author_profile',array(
        'default'    => true,
        'sanitize_callback' => 'sanitize_text_field',
      ));
      $wp_customize->add_control('simple_days_single_author_profile',array(
        'label'   => esc_html__( 'Display', 'simple-days'),
        'description' => esc_html__('About the author(Author profile)', 'simple-days'),
        'section' => 'simple_days_single',
        'type' => 'checkbox',
      ));



      $wp_customize->add_setting('related_post',array('sanitize_callback' => 'absint',));
      $wp_customize->add_control('related_post',array(
        'section' => 'simple_days_single',
        'type' => 'hidden'
      ));
      $wp_customize->selective_refresh->add_partial( 'related_post', array(
         'selector' => '#related_posts',
      ));

      $wp_customize->add_setting( 'simple_days_single_related_post',array(
        'default'    => true,
        'sanitize_callback' => 'sanitize_text_field',
      ));
      $wp_customize->add_control( 'simple_days_single_related_post',array(
        'label'   => esc_html__( 'Display', 'simple-days'),
        'description' => esc_html__('Related Posts', 'simple-days'),
        'section' => 'simple_days_single',
        'type' => 'checkbox',
      ));

      $wp_customize->add_setting( 'simple_days_single_related_post_number', array(
        'default' => 9,
        'sanitize_callback' => 'absint',
      ));
      $wp_customize->add_control( 'simple_days_single_related_post_number', array(
        'label' => esc_html__( 'Related Posts view count.', 'simple-days' ),
        'description' => esc_html__( 'multiples of 3 (min3 max18)', 'simple-days' ),
        'section' => 'simple_days_single', // Add a default or your own section
        'type' => 'number',
        'input_attrs' => array(
            'min' => '3', 'step' => '3', 'max' => '18',
        ),
      ));






      $wp_customize->add_section('simple_days_page',array(
        'title' => esc_html_x('Page', 'customizer' ,'simple-days'),
        'panel' => 'simple_days_setting',
      ));

      $wp_customize->add_setting('page_thumbnail',array('sanitize_callback' => 'absint',));
      $wp_customize->add_control('page_thumbnail',array(
        'section' => 'simple_days_page',
        'type' => 'hidden'
      ));
      $wp_customize->selective_refresh->add_partial( 'page_thumbnail', array(
         'selector' => '.page_thumbnail',
      ));

      $wp_customize->add_setting( 'simple_days_page_thumbnail',array(
        'default'    => true,
        'sanitize_callback' => 'sanitize_text_field',
      ));
      $wp_customize->add_control( 'simple_days_page_thumbnail',array(
        'label'   => esc_html__( 'Display', 'simple-days'),
        'description' => esc_html__('Thumbnail', 'simple-days'),
        'section' => 'simple_days_page',
        'type' => 'checkbox',
      ));

      $wp_customize->add_setting('page_author',array('sanitize_callback' => 'absint',));
      $wp_customize->add_control('page_author',array(
        'section' => 'simple_days_page',
        'type' => 'hidden'
      ));
      $wp_customize->selective_refresh->add_partial( 'page_author', array(
         'selector' => '.page_author',
      ));
      $wp_customize->add_setting( 'simple_days_page_author',array(
        'default'    => false,
        'sanitize_callback' => 'sanitize_text_field',
      ));
      $wp_customize->add_control( 'simple_days_page_author',array(
        'label'   => esc_html__( 'Display', 'simple-days'),
        'description' => esc_html__('Author', 'simple-days'),
        'section' => 'simple_days_page',
        'type' => 'checkbox',
      ));


      $wp_customize->add_setting('page_date',array('sanitize_callback' => 'absint',));
      $wp_customize->add_control('page_date',array(
        'section' => 'simple_days_page',
        'type' => 'hidden'
      ));
      $wp_customize->selective_refresh->add_partial( 'page_date', array(
         'selector' => '.page_date',
      ));
      $wp_customize->add_setting( 'simple_days_page_date',array(
        'default'    => false,
        'sanitize_callback' => 'sanitize_text_field',
      ));
      $wp_customize->add_control( 'simple_days_page_date',array(
        'label'   => esc_html__( 'Display', 'simple-days'),
        'description' => esc_html__('Date', 'simple-days'),
        'section' => 'simple_days_page',
        'type' => 'checkbox',
      ));


      $wp_customize->add_setting( 'simple_days_page_social_share',array(
        'default'    => false,
        'sanitize_callback' => 'sanitize_text_field',
      ));
      $wp_customize->add_control( 'simple_days_page_social_share',array(
        'label'   => esc_html__( 'Display', 'simple-days'),
        'description' => esc_html__('Social share', 'simple-days'),
        'section' => 'simple_days_page',
        'type' => 'checkbox',
      ));

      $wp_customize->add_setting( 'simple_days_page_author_profile',array(
        'default'    => false,
        'sanitize_callback' => 'sanitize_text_field',
      ));
      $wp_customize->add_control( 'simple_days_page_author_profile',array(
        'label'   => esc_html__( 'Display', 'simple-days'),
        'description' => esc_html__('About the author(Author profile)', 'simple-days'),
        'section' => 'simple_days_page',
        'type' => 'checkbox',
      ));

      $wp_customize->add_setting( 'simple_days_page_related_page',array(
        'default'    => false,
        'sanitize_callback' => 'sanitize_text_field',
      ));
      $wp_customize->add_control( 'simple_days_page_related_page',array(
        'label'   => esc_html__( 'Display', 'simple-days'),
        'description' => esc_html__('Related Pages', 'simple-days').'<br />'.esc_html__('The plugin [pages-with-category-and-tag] is needed', 'simple-days'),
        'section' => 'simple_days_page',
        'type' => 'checkbox',
      ));

      $wp_customize->add_setting( 'simple_days_page_related_post_number', array(
        'default' => 9,
        'sanitize_callback' => 'absint',
      ));
      $wp_customize->add_control( 'simple_days_page_related_post_number', array(
        'label' => esc_html__( 'Related Pages view count.', 'simple-days' ),
        'description' => esc_html__( 'multiples of 3 (min3 max18)', 'simple-days' ),
        'section' => 'simple_days_page', // Add a default or your own section
        'type' => 'number',
        'input_attrs' => array(
            'min' => '3', 'step' => '3', 'max' => '18',
        ),
      ));










      $wp_customize->add_setting('breadcrumbs',array('sanitize_callback' => 'absint',));
      $wp_customize->add_control('breadcrumbs',array(
        'section' => 'simple_days_breadcrumbs',
        'type' => 'hidden'
      ));
      $wp_customize->selective_refresh->add_partial( 'breadcrumbs', array(
         'selector' => '#breadcrumb',
      ));

      $wp_customize->add_section('simple_days_breadcrumbs',array(
        'title' => esc_html__('Breadcrumbs','simple-days'),
        'panel' => 'simple_days_setting',
      ));


      $wp_customize->add_setting( 'simple_days_breadcrumbs_display',array(
        'default'    => true,
        'sanitize_callback' => 'sanitize_text_field',
      ));
      $wp_customize->add_control( 'simple_days_breadcrumbs_display',array(
        'label'   => esc_html__( 'Display', 'simple-days'),
        'description' => esc_html__('Breadcrumbs', 'simple-days'),
        'section' => 'simple_days_breadcrumbs',
        'type' => 'checkbox',
      ));

      $wp_customize->add_setting( 'simple_days_breadcrumbs_current',array(
        'default'    => true,
        'sanitize_callback' => 'sanitize_text_field',
      ));
      $wp_customize->add_control( 'simple_days_breadcrumbs_current',array(
        'label'   => esc_html__( 'Display', 'simple-days'),
        'description' => esc_html__('Current name', 'simple-days'),
        'section' => 'simple_days_breadcrumbs',
        'type' => 'checkbox',
      ));


      $delimiter = ' &raquo; ';
      $wp_customize->add_setting( 'simple_days_breadcrumbs_delimiter',array(
        'default'           => $delimiter,
        'sanitize_callback' => 'wp_strip_all_tags',
      ));
      $wp_customize->add_control('simple_days_breadcrumbs_delimiter',array(
        'label'   => esc_html__( 'Delimiter', 'simple-days'),
        'description' => esc_html__('If you leave this box blank,nothing is displayed.', 'simple-days'),
        'section' => 'simple_days_breadcrumbs',
        'type'    => 'editor',
      ));

      $wp_customize->add_setting( 'simple_days_breadcrumbs_homeicon',array(
        'default'           => 'fa fa-home',
        'sanitize_callback' => 'wp_strip_all_tags',
      ));
      $wp_customize->add_control('simple_days_breadcrumbs_homeicon',array(
        'label'   => esc_html__( 'Home icon', 'simple-days'),
        'description' => esc_html__('Support Font Awesome4 only.', 'simple-days').'<br />'.esc_html__('default&#58;', 'simple-days').esc_html('fa fa-home').'<br />'.esc_html__('If you leave this box blank,nothing is displayed.', 'simple-days'),
        'section' => 'simple_days_breadcrumbs',
        'type'    => 'text',
      ));

      $wp_customize->add_setting( 'simple_days_breadcrumbs_treeicon',array(
        'default'           => 'fa fa-folder-open-o',
        'sanitize_callback' => 'wp_strip_all_tags',
      ));
      $wp_customize->add_control('simple_days_breadcrumbs_treeicon',array(
        'label'   => esc_html__( 'Tree icon', 'simple-days'),
        'description' => esc_html__('Support Font Awesome4 only.', 'simple-days').'<br />'.esc_html__('default&#58;', 'simple-days').esc_html('fa fa-folder-open-o').'<br />'.esc_html__('If you leave this box blank,nothing is displayed.', 'simple-days'),
        'section' => 'simple_days_breadcrumbs',
        'type'    => 'text',
      ));

      $wp_customize->add_setting( 'simple_days_breadcrumbs_currenticon',array(
        'default'           => 'fa fa-file-text-o',
        'sanitize_callback' => 'wp_strip_all_tags',
      ));
      $wp_customize->add_control('simple_days_breadcrumbs_currenticon',array(
        'label'   => esc_html__( 'Current icon', 'simple-days'),
        'description' => esc_html__('Support Font Awesome4 only.', 'simple-days').'<br />'.esc_html__('default&#58;', 'simple-days').esc_html('fa fa-file-text-o').'<br />'.esc_html__('If you leave this box blank,nothing is displayed.', 'simple-days'),
        'section' => 'simple_days_breadcrumbs',
        'type'    => 'text',
      ));






      $wp_customize->add_section('simple_days_social_account_setting',array(
        'title' => esc_html__('Social Account','simple-days'),
        'panel' => 'simple_days_setting',
      ));


  $wp_customize->add_setting( 'simple_days_social_account_facebook',array(
        'default'           => '',
        'sanitize_callback' => 'wp_strip_all_tags',
  ));
  $wp_customize->add_control('simple_days_social_account_facebook',array(
        'label'   => esc_html__( 'Facebook', 'simple-days'),
        'description' => esc_html__('e.g.&nbsp;', 'simple-days').' facebook.com/<strong class="highlighter">&lowast;&lowast;&lowast;&lowast;&lowast;&lowast;</strong><br />'.esc_html__('type the &lowast; part of your url', 'simple-days'),
        'section' => 'simple_days_social_account_setting',
        'type'    => 'text',
  ));

  $wp_customize->add_setting( 'simple_days_social_account_twitter',array(
        'default'           => '',
        'sanitize_callback' => 'wp_strip_all_tags',
  ));
  $wp_customize->add_control('simple_days_social_account_twitter',array(
        'label'   => esc_html__( 'Twitter', 'simple-days'),
        'description' => esc_html__('e.g.&nbsp;', 'simple-days').' twitter.com/<strong class="highlighter">&lowast;&lowast;&lowast;&lowast;&lowast;&lowast;</strong><br />'.esc_html__('type the &lowast; part of your url', 'simple-days'),
        'section' => 'simple_days_social_account_setting',
        'type'    => 'text',
  ));

  $wp_customize->add_setting( 'simple_days_social_account_linkedin',array(
        'default'           => '',
        'sanitize_callback' => 'wp_strip_all_tags',
  ));
  $wp_customize->add_control('simple_days_social_account_linkedin',array(
        'label'   => esc_html__( 'LinkedIn', 'simple-days'),
        'description' => esc_html__('e.g.&nbsp;', 'simple-days').' linkedin.com/in/<strong class="highlighter">&lowast;&lowast;&lowast;&lowast;&lowast;&lowast;</strong><br />'.esc_html__('type the &lowast; part of your url', 'simple-days'),
        'section' => 'simple_days_social_account_setting',
        'type'    => 'text',
  ));

  $wp_customize->add_setting( 'simple_days_social_account_instagram',array(
        'default'           => '',
        'sanitize_callback' => 'wp_strip_all_tags',
  ));
  $wp_customize->add_control('simple_days_social_account_instagram',array(
        'label'   => esc_html__( 'Instagram', 'simple-days'),
        'description' => esc_html__('e.g.&nbsp;', 'simple-days').' instagram.com/<strong class="highlighter">&lowast;&lowast;&lowast;&lowast;&lowast;&lowast;</strong><br />'.esc_html__('type the &lowast; part of your url', 'simple-days'),
        'section' => 'simple_days_social_account_setting',
        'type'    => 'text',
  ));

  $wp_customize->add_setting( 'simple_days_social_account_googleplus',array(
        'default'           => '',
        'sanitize_callback' => 'wp_strip_all_tags',
  ));
  $wp_customize->add_control('simple_days_social_account_googleplus',array(
        'label'   => esc_html__( 'Google+', 'simple-days'),
        'description' => esc_html__('e.g.&nbsp;', 'simple-days').' plus.google.com/<strong class="highlighter">&lowast;&lowast;&lowast;&lowast;&lowast;&lowast;</strong><br />'.esc_html__('type the &lowast; part of your url', 'simple-days'),
        'section' => 'simple_days_social_account_setting',
        'type'    => 'text',
  ));
  $wp_customize->add_setting( 'simple_days_social_account_pinterest',array(
        'default'           => '',
        'sanitize_callback' => 'wp_strip_all_tags',
  ));
  $wp_customize->add_control('simple_days_social_account_pinterest',array(
        'label'   => esc_html__( 'Pinterest', 'simple-days'),
        'description' => esc_html__('e.g.&nbsp;', 'simple-days').' pinterest.com/<strong class="highlighter">&lowast;&lowast;&lowast;&lowast;&lowast;&lowast;</strong><br />'.esc_html__('type the &lowast; part of your url', 'simple-days'),
        'section' => 'simple_days_social_account_setting',
        'type'    => 'text',
  ));
  $wp_customize->add_setting( 'simple_days_social_account_flickr',array(
        'default'           => '',
        'sanitize_callback' => 'wp_strip_all_tags',
  ));
  $wp_customize->add_control('simple_days_social_account_flickr',array(
        'label'   => esc_html__( 'Flickr', 'simple-days'),
        'description' => esc_html__('e.g.&nbsp;', 'simple-days').' flickr.com/photos/<strong class="highlighter">&lowast;&lowast;&lowast;&lowast;&lowast;&lowast;</strong><br />'.esc_html__('type the &lowast; part of your url', 'simple-days'),
        'section' => 'simple_days_social_account_setting',
        'type'    => 'text',
  ));
  $wp_customize->add_setting( 'simple_days_social_account_github',array(
        'default'           => '',
        'sanitize_callback' => 'wp_strip_all_tags',
  ));
  $wp_customize->add_control('simple_days_social_account_github',array(
        'label'   => esc_html__( 'Github', 'simple-days'),
        'description' => esc_html__('e.g.&nbsp;', 'simple-days').' github.com/<strong class="highlighter">&lowast;&lowast;&lowast;&lowast;&lowast;&lowast;</strong><br />'.esc_html__('type the &lowast; part of your url', 'simple-days'),
        'section' => 'simple_days_social_account_setting',
        'type'    => 'text',
  ));
  $wp_customize->add_setting( 'simple_days_social_account_github',array(
        'default'           => '',
        'sanitize_callback' => 'wp_strip_all_tags',
  ));
  $wp_customize->add_control('simple_days_social_account_github',array(
        'label'   => esc_html__( 'Github', 'simple-days'),
        'description' => esc_html__('e.g.&nbsp;', 'simple-days').' github.com/<strong class="highlighter">&lowast;&lowast;&lowast;&lowast;&lowast;&lowast;</strong><br />'.esc_html__('type the &lowast; part of your url', 'simple-days'),
        'section' => 'simple_days_social_account_setting',
        'type'    => 'text',
  ));
  $wp_customize->add_setting( 'simple_days_social_account_youtube',array(
        'default'           => '',
        'sanitize_callback' => 'wp_strip_all_tags',
  ));
  $wp_customize->add_control('simple_days_social_account_youtube',array(
        'label'   => esc_html__( 'Youtube', 'simple-days'),
        'description' => esc_html__('e.g.&nbsp;', 'simple-days').' youtube.com/<strong class="highlighter">&lowast;&lowast;&lowast;&lowast;&lowast;&lowast;</strong><br />'.esc_html__('type the &lowast; part of your url', 'simple-days'),
        'section' => 'simple_days_social_account_setting',
        'type'    => 'text',
  ));
  $wp_customize->add_setting( 'simple_days_social_account_vimeo',array(
        'default'           => '',
        'sanitize_callback' => 'wp_strip_all_tags',
  ));
  $wp_customize->add_control('simple_days_social_account_vimeo',array(
        'label'   => esc_html__( 'Vimeo', 'simple-days'),
        'description' => esc_html__('e.g.&nbsp;', 'simple-days').' vimeo.com/<strong class="highlighter">&lowast;&lowast;&lowast;&lowast;&lowast;&lowast;</strong><br />'.esc_html__('type the &lowast; part of your url', 'simple-days'),
        'section' => 'simple_days_social_account_setting',
        'type'    => 'text',
  ));
  $wp_customize->add_setting( 'simple_days_social_account_tumblr',array(
        'default'           => '',
        'sanitize_callback' => 'wp_strip_all_tags',
  ));
  $wp_customize->add_control('simple_days_social_account_tumblr',array(
        'label'   => esc_html__( 'Tumblr', 'simple-days'),
        'description' => esc_html__('e.g.&nbsp;', 'simple-days').' <strong class="highlighter">&lowast;&lowast;&lowast;&lowast;&lowast;&lowast;</strong>.tumblr.com<br />'.esc_html__('type the &lowast; part of your url', 'simple-days'),
        'section' => 'simple_days_social_account_setting',
        'type'    => 'text',
  ));
  $wp_customize->add_setting( 'simple_days_social_account_hatenabookmark',array(
        'default'           => '',
        'sanitize_callback' => 'wp_strip_all_tags',
  ));
  $wp_customize->add_control('simple_days_social_account_hatenabookmark',array(
        'label'   => esc_html__( 'Hatena Bookmark', 'simple-days'),
        'description' => esc_html__('e.g.&nbsp;', 'simple-days').' b.hatena.ne.jp/<strong class="highlighter">&lowast;&lowast;&lowast;&lowast;&lowast;&lowast;</strong><br />'.esc_html__('type the &lowast; part of your url', 'simple-days'),
        'section' => 'simple_days_social_account_setting',
        'type'    => 'text',
  ));
  $wp_customize->add_setting( 'simple_days_social_account_line',array(
        'default'           => '',
        'sanitize_callback' => 'wp_strip_all_tags',
  ));
  $wp_customize->add_control('simple_days_social_account_line',array(
        'label'   => esc_html__( 'Line', 'simple-days'),
        'description' => esc_html__('e.g.&nbsp;', 'simple-days').' line.naver.jp/ti/p/<strong class="highlighter">&lowast;&lowast;&lowast;&lowast;&lowast;&lowast;</strong><br />'.esc_html__('type the &lowast; part of your url', 'simple-days'),
        'section' => 'simple_days_social_account_setting',
        'type'    => 'text',
  ));

  $wp_customize->add_setting( 'simple_days_social_account_facebook_app_id',array(
        'default'           => '',
        'sanitize_callback' => 'wp_strip_all_tags',
  ));
  $wp_customize->add_control('simple_days_social_account_facebook_app_id',array(
        'label'   => esc_html__( 'Facebook App ID', 'simple-days'),
        'description' => esc_html__('e.g.&nbsp;', 'simple-days').esc_html('1234567890'),
        'section' => 'simple_days_social_account_setting',
        'type'    => 'text',
  ));

  $wp_customize->add_setting( 'simple_days_social_account_facebook_admins',array(
        'default'           => '',
        'sanitize_callback' => 'wp_strip_all_tags',
  ));
  $wp_customize->add_control('simple_days_social_account_facebook_admins',array(
        'label'   => esc_html__( 'Facebook fb:admins', 'simple-days'),
        'description' => esc_html__('e.g.&nbsp;', 'simple-days').esc_html('1234567890'),
        'section' => 'simple_days_social_account_setting',
        'type'    => 'text',
  ));



      $wp_customize->add_section('simple_days_social_share_setting',array(
        'title' => esc_html__('Social Share','simple-days'),
        'panel' => 'simple_days_setting',
      ));

      $wp_customize->add_setting('sns_share',array('sanitize_callback' => 'absint',));
      $wp_customize->add_control('sns_share',array(
        'section' => 'simple_days_social_share_setting',
        'type' => 'hidden'
      ));
      $wp_customize->selective_refresh->add_partial( 'sns_share', array(
         'selector' => '.social_share_list',
      ));

      $wp_customize->add_setting( 'simple_days_social_share',array(
        'default'    => 'false',
        'sanitize_callback' => 'sanitize_text_field',
      ));
      $wp_customize->add_control( 'simple_days_social_share',array(
        'label'   => esc_html__( 'Display Style', 'simple-days'),
        'description' => esc_html__('Social share', 'simple-days'),
        'section' => 'simple_days_social_share_setting',
        'type'     => 'radio',
        'choices'  => array(
          'false' => esc_html__( 'Disable', 'simple-days' ),
          'icon_square' => esc_html__( 'square', 'simple-days' ),
          'icon_circle' => esc_html__( 'circle', 'simple-days' ),
          'icon_rectangle' => esc_html__( 'rectangle', 'simple-days' ),
          'icon_character' => esc_html__( 'character', 'simple-days' ),
          'icon_hollow_square' => esc_html__( 'hollow square', 'simple-days' ),
          'icon_hollow_circle' => esc_html__( 'hollow circle', 'simple-days' ),
          'icon_hollow_rectangle' => esc_html__( 'hollow rectangle', 'simple-days' ),
        ),
      ));

      $wp_customize->add_setting( 'simple_days_social_share_size',array(
        'default'    => '',
        'sanitize_callback' => 'sanitize_text_field',
      ));
      $wp_customize->add_control( 'simple_days_social_share_size',array(
        'label'   => esc_html__( 'Icon Size', 'simple-days'),
        'section' => 'simple_days_social_share_setting',
        'type'     => 'radio',
        'choices'  => array(
          'icon_small' => esc_html__( 'small', 'simple-days' ),
          '' => esc_html__( 'medium', 'simple-days' ),
          'icon_large' => esc_html__( 'large', 'simple-days' ),
          'icon_xlarge' => esc_html__( 'extra large', 'simple-days' ),
        ),
      ));



      $sns_share_name = array(
        'none'               => '-',
        'buffer'             => esc_html__('buffer', 'simple-days'),
        'digg'               => esc_html__('digg', 'simple-days'),
        'mail'               => esc_html__('Email', 'simple-days'),
        'evernote'           => esc_html__('Evernote', 'simple-days'),
        'facebook'           => esc_html__('Facebook', 'simple-days'),
        'googleplus'         => esc_html__('Google+', 'simple-days'),
        'hatenabookmark'     => esc_html__('Hatena Bookmark', 'simple-days'),
        'line'               => esc_html__('Line', 'simple-days'),
        'linkedin'           => esc_html__('LinkedIn', 'simple-days'),
        'messenger'          => esc_html__('Messenger', 'simple-days'),
        'pinterest'          => esc_html__('Pinterest', 'simple-days'),
        'pocket'             => esc_html__('Pocket', 'simple-days'),
        'reddit'             => esc_html__('Reddit', 'simple-days'),
        'tumblr'             => esc_html__('Tumblr', 'simple-days'),
        'twitter'            => esc_html__('Twitter', 'simple-days'),
        'whatsapp'           => esc_html__('WhatsApp', 'simple-days'),
      );








      $i = 1;
      while($i <= 10){
        $wp_customize->add_setting( 'simple_days_sns_share_'.$i,array(
          'default'       => 'none',
          'sanitize_callback' => 'simple_days_sns_name_sanitize',
        ));
        $wp_customize->add_control('simple_days_sns_share_'.$i,array(
          
          'label'   => sprintf(esc_html__( 'Social share Icon #%s', 'simple-days'),$i),
          'section' => 'simple_days_social_share_setting',
          'type'    => 'select',
          'choices' => $sns_share_name,
          'priority'  => $i+100,
        ));
        $i++;
      }






      $wp_customize->add_section('simple_days_social_cta_setting',array(
        'title' => esc_html__('Social CTA','simple-days'),
        'panel' => 'simple_days_setting',
      ));

      $wp_customize->add_setting( 'simple_days_social_cta',array(
        'default'    => false,
        'sanitize_callback' => 'sanitize_text_field',
      ));
      $wp_customize->add_control( 'simple_days_social_cta',array(
        'label'   => esc_html__( 'Display', 'simple-days'),
        'description' => esc_html__('call-to-action under in the contents of the post', 'simple-days'),
        'section' => 'simple_days_social_cta_setting',
        'type' => 'checkbox',
      ));
      $wp_customize->add_setting( 'simple_days_social_cta_page',array(
        'default'    => false,
        'sanitize_callback' => 'sanitize_text_field',
      ));
      $wp_customize->add_control( 'simple_days_social_cta_page',array(
        'label'   => esc_html__( 'Display', 'simple-days'),
        'description' => esc_html__('call-to-action under in the contents of the page', 'simple-days'),
        'section' => 'simple_days_social_cta_setting',
        'type' => 'checkbox',
      ));
  $wp_customize->add_setting( 'simple_days_social_cta_heading_text',array(
        'default'           => esc_html__('Follow us', 'simple-days'),
        'sanitize_callback' => 'wp_strip_all_tags',
  ));
  $wp_customize->add_control('simple_days_social_cta_heading_text',array(
        'label'   => esc_html__( 'heading text', 'simple-days'),
        'section' => 'simple_days_social_cta_setting',
        'type'    => 'text',
  ));
  $wp_customize->add_setting( 'simple_days_social_cta_end_text',array(
        'default'           => esc_html__('We will keep you updated', 'simple-days'),
        'sanitize_callback' => 'wp_strip_all_tags',
  ));
  $wp_customize->add_control('simple_days_social_cta_end_text',array(
        'label'   => esc_html__( 'end text', 'simple-days'),
        'section' => 'simple_days_social_cta_setting',
        'type'    => 'text',
  ));
      $wp_customize->add_setting( 'simple_days_social_cta_facebook',array(
        'default'    => false,
        'sanitize_callback' => 'sanitize_text_field',
      ));
      $wp_customize->add_control( 'simple_days_social_cta_facebook',array(
        'label'   => esc_html__( 'Display', 'simple-days'),
        'description' => esc_html__('Facebook', 'simple-days'),
        'section' => 'simple_days_social_cta_setting',
        'type' => 'checkbox',
      ));
      $wp_customize->add_setting( 'simple_days_social_cta_facebook_script',array(
        'default'    => false,
        'sanitize_callback' => 'sanitize_text_field',
      ));
      $wp_customize->add_control( 'simple_days_social_cta_facebook_script',array(
        'label'   => esc_html__( 'Enable', 'simple-days'),
        'description' => esc_html__('required Facebook script.', 'simple-days').'<br />'.esc_html__('be careful not to conflict', 'simple-days'),
        'section' => 'simple_days_social_cta_setting',
        'type' => 'checkbox',
      ));
      $wp_customize->add_setting( 'simple_days_social_cta_twitter',array(
        'default'    => false,
        'sanitize_callback' => 'sanitize_text_field',
      ));
      $wp_customize->add_control( 'simple_days_social_cta_twitter',array(
        'label'   => esc_html__( 'Display', 'simple-days'),
        'description' => esc_html__('Twitter', 'simple-days'),
        'section' => 'simple_days_social_cta_setting',
        'type' => 'checkbox',
      ));





      $wp_customize->add_section('simple_days_social_link_setting',array(
        'title' => esc_html__('Social Links Widget','simple-days'),
        'panel' => 'simple_days_setting',
      ));

      $wp_customize->add_setting('social_link',array('sanitize_callback' => 'absint',));
      $wp_customize->add_control('social_link',array(
        'section' => 'simple_days_social_link_setting',
        'type' => 'hidden'
      ));
      $wp_customize->selective_refresh->add_partial( 'social_link', array(
         'selector' => '.social_list .sns_link_icon li:first-child',
      ));

      $wp_customize->add_setting( 'simple_days_social_link_widget',array(
        'default'    => false,
        'sanitize_callback' => 'sanitize_text_field',
      ));
      $wp_customize->add_control( 'simple_days_social_link_widget',array(
        'label'   => esc_html__( 'Enable', 'simple-days'),
        'description' => esc_html__('Add Social Links Widget', 'simple-days'),
        'section' => 'simple_days_social_link_setting',
        'type' => 'checkbox',
      ));




      $wp_customize->add_setting( 'simple_days_social_link_shape',array(
        'default'    => 'icon_square',
        'sanitize_callback' => 'sanitize_text_field',
      ));

      $wp_customize->add_control( 'simple_days_social_link_shape',array(
        'label'   => esc_html__( 'Display Style', 'simple-days'),
        'description' => esc_html__('Social Links', 'simple-days'),
        'section' => 'simple_days_social_link_setting',
        'type'     => 'radio',
        'choices'  => array(
          'icon_square' => esc_html__( 'square', 'simple-days' ),
          'icon_circle' => esc_html__( 'circle', 'simple-days' ),
          'icon_rectangle' => esc_html__( 'rectangle', 'simple-days' ),
          'icon_character' => esc_html__( 'character', 'simple-days' ),
          'icon_hollow_square' => esc_html__( 'hollow square', 'simple-days' ),
          'icon_hollow_circle' => esc_html__( 'hollow circle', 'simple-days' ),
          'icon_hollow_rectangle' => esc_html__( 'hollow rectangle', 'simple-days' ),
        ),
      ));

      $wp_customize->add_setting( 'simple_days_social_link_size',array(
        'default'    => '',
        'sanitize_callback' => 'sanitize_text_field',
      ));
      $wp_customize->add_control( 'simple_days_social_link_size',array(
        'label'   => esc_html__( 'Icon Size', 'simple-days'),
        'section' => 'simple_days_social_link_setting',
        'type'     => 'radio',
        'choices'  => array(
          'icon_small' => esc_html__( 'small', 'simple-days' ),
          '' => esc_html__( 'medium', 'simple-days' ),
          'icon_large' => esc_html__( 'large', 'simple-days' ),
          'icon_xlarge' => esc_html__( 'extra large', 'simple-days' ),
        ),
      ));
  $wp_customize->add_setting( 'simple_days_profile_social_link_icon_color',array(
    'default'    => false,
    'sanitize_callback' => 'sanitize_text_field',
  ));
  $wp_customize->add_control( 'simple_days_profile_social_link_icon_color',array(
    'label'   => esc_html__( 'Enable', 'simple-days'),
    'description' => esc_html__('Dark color', 'simple-days'),
    'section' => 'simple_days_social_link_setting',
    'type' => 'checkbox',
  ));

      $wp_customize->add_setting('sns_link_intro',array('sanitize_callback' => 'absint',));
      $wp_customize->add_control('sns_link_intro',array(
        'section' => 'simple_days_social_link_setting',
        'type' => 'hidden'
      ));
      $wp_customize->selective_refresh->add_partial( 'sns_link_intro', array(
         'selector' => '.sns_intro',
      ));

      $wp_customize->add_setting( 'simple_days_social_link_intro',array(
        'default'           => esc_html__( 'Follow us on social media', 'simple-days'),
        'sanitize_callback' => 'wp_strip_all_tags',
      ));
      $wp_customize->add_control('simple_days_social_link_intro',array(
        'label'   => esc_html__( 'Follow message', 'simple-days'),
        'section' => 'simple_days_social_link_setting',
        'type'    => 'text',
      ));

      $sns_link_name = array(
        'none'             => '-',
        'facebook'         => esc_html__('Facebook', 'simple-days'),
        'feedly'           => esc_html__('Feedly', 'simple-days'),
        'flickr'           => esc_html__('Flickr', 'simple-days'),
        'github'           => esc_html__('Github', 'simple-days'),
        'googleplus'       => esc_html__('Google+', 'simple-days'),
        'hatenabookmark'   => esc_html__('Hatena Bookmark', 'simple-days'),
        'instagram'        => esc_html__('Instagram', 'simple-days'),
        'line'             => esc_html__('Line', 'simple-days'),
        'linkedin'         => esc_html__('LinkedIn', 'simple-days'),
        'pinterest'        => esc_html__('Pinterest', 'simple-days'),
        'rss'              => esc_html__('RSS', 'simple-days'),
        'tumblr'           => esc_html__('Tumblr', 'simple-days'),
        'twitter'          => esc_html__('Twitter', 'simple-days'),
        'vimeo'            => esc_html__('Vimeo', 'simple-days'),
        'youtube'          => esc_html__('Youtube', 'simple-days'),
      );








      $i = 1;
      while($i <= 10){
        $wp_customize->add_setting( 'simple_days_sns_icon_'.$i,array(
          'default'       => 'none',
          'sanitize_callback' => 'simple_days_sns_name_sanitize',
        ));
        $wp_customize->add_control('simple_days_sns_icon_'.$i,array(
          
          'label'   => sprintf(esc_html__( 'Social Icon #%s', 'simple-days'),$i),
          'section' => 'simple_days_social_link_setting',
          'type'    => 'select',
          'choices' => $sns_link_name,
          'priority'  => $i+100,
        ));
        $i++;
      }


      $wp_customize->add_setting('profile',array('sanitize_callback' => 'absint',));
      $wp_customize->add_control('profile',array(
        'section' => 'simple_days_profile_setting',
        'type' => 'hidden'
      ));
      $wp_customize->selective_refresh->add_partial( 'profile', array(
         'selector' => '.profile_box',
      ));

  $wp_customize->add_section('simple_days_profile_setting',array(
    'title' => esc_html__('Profile Widget', 'simple-days'),
    'panel' => 'simple_days_setting',
  ));
  $wp_customize->add_setting( 'simple_days_profile_widget',array(
    'default'    => false,
    'sanitize_callback' => 'sanitize_text_field',
  ));
  $wp_customize->add_control( 'simple_days_profile_widget',array(
    'label'   => esc_html__( 'Enable', 'simple-days'),
    'description' => esc_html__('Add Profile Widget', 'simple-days'),
    'section' => 'simple_days_profile_setting',
    'type' => 'checkbox',
  ));
  $wp_customize->add_setting( 'simple_days_profile_title',array(
    'default'           => esc_html__( 'Profile', 'simple-days'),
    'sanitize_callback' => 'wp_strip_all_tags',
  ));
  $wp_customize->add_control('simple_days_profile_title',array(
    'label'   => esc_html__( 'Title', 'simple-days'),
    'section' => 'simple_days_profile_setting',
    'type'    => 'text',
  ));
  $wp_customize->add_setting( 'simple_days_profile_name',array(
    'default'           => '',
    'sanitize_callback' => 'wp_strip_all_tags',
  ));
  $wp_customize->add_control('simple_days_profile_name',array(
    'label'   => esc_html__( 'Name', 'simple-days'),
    'section' => 'simple_days_profile_setting',
    'type'    => 'text',
  ));
  $wp_customize->add_setting( 'simple_days_profile_image',array(
        'default'    => '',
        'sanitize_callback' => 'simple_days_sanitize_image_file',
  ));
  $wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'simple_days_profile_image', array(
        'label' => esc_html__( 'Profile image', 'simple-days'),
        'description' => esc_html__( 'Profile use this image.', 'simple-days'),
        'section' => 'simple_days_profile_setting',
  )));
  $wp_customize->add_setting( 'simple_days_profile_image_wrap', array(
    'default'           => 'circle',
    'sanitize_callback' => 'simple_days_sanitize_radio',
    )
  );
  $wp_customize->add_control( 'simple_days_profile_image_wrap', array(
    'label'    => esc_html__( 'Profile image display shape', 'simple-days' ),
    'section'  => 'simple_days_profile_setting',
    'type'     => 'radio',
    'choices'  => array(
      'circle' => esc_html__( 'Circle', 'simple-days' ),
      'square' => esc_html__( 'Square', 'simple-days' ),
    ),
  ));
  $wp_customize->add_setting( 'simple_days_profile_background_image',array(
        'default'    => '',
        'sanitize_callback' => 'simple_days_sanitize_image_file',
  ));
  $wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'simple_days_profile_background_image', array(
        'label' => esc_html__( 'Background image', 'simple-days'),
        'description' => esc_html__( 'Background use this image.', 'simple-days'),
        'section' => 'simple_days_profile_setting',
  )));

      $wp_customize->add_setting( 'simple_days_profile_text',array(
        'default'           => '',
        'sanitize_callback' => 'wp_kses_post',
      ));
      $wp_customize->add_control('simple_days_profile_text',array(
        'label'   => esc_html__( 'Profile text', 'simple-days'),
        'section' => 'simple_days_profile_setting',
        'type'    => 'textarea',
      ));
      $wp_customize->add_setting( 'simple_days_profile_read_more_url',array(
        'default'           => '',
        'sanitize_callback' => 'wp_kses_post',
      ));
      $wp_customize->add_control('simple_days_profile_read_more_url',array(
        'label'   => esc_html__( 'Read more URL', 'simple-days'),
        'section' => 'simple_days_profile_setting',
        'type'    => 'text',
      ));
      $wp_customize->add_setting( 'simple_days_profile_read_more_text',array(
        'default'           => esc_html__( 'Read More', 'simple-days' ),
        'sanitize_callback' => 'wp_kses_post',
      ));
      $wp_customize->add_control('simple_days_profile_read_more_text',array(
        'label'   => esc_html__( 'Read more text', 'simple-days'),
        'section' => 'simple_days_profile_setting',
        'type'    => 'text',
      ));
  $wp_customize->add_setting( 'simple_days_profile_read_more_blank',array(
    'default'    => false,
    'sanitize_callback' => 'sanitize_text_field',
  ));
  $wp_customize->add_control( 'simple_days_profile_read_more_blank',array(
    'label'   => esc_html__( 'Enable', 'simple-days'),
    'description' => esc_html__('Read more link open new window.', 'simple-days'),
    'section' => 'simple_days_profile_setting',
    'type' => 'checkbox',
  ));


      $wp_customize->add_setting( 'simple_days_profile_social_link_shape',array(
        'default'    => 'icon_square',
        'sanitize_callback' => 'sanitize_text_field',
      ));

      $wp_customize->add_control( 'simple_days_profile_social_link_shape',array(
        'label'   => esc_html__( 'Social Links', 'simple-days'),
        'description' => esc_html__('Display Style', 'simple-days'),
        'section' => 'simple_days_profile_setting',
        'type'     => 'radio',
        'choices'  => array(
          'icon_square' => esc_html__( 'square', 'simple-days' ),
          'icon_circle' => esc_html__( 'circle', 'simple-days' ),
          'icon_rectangle' => esc_html__( 'rectangle', 'simple-days' ),
          'icon_character' => esc_html__( 'character', 'simple-days' ),
          'icon_hollow_square' => esc_html__( 'hollow square', 'simple-days' ),
          'icon_hollow_circle' => esc_html__( 'hollow circle', 'simple-days' ),
          'icon_hollow_rectangle' => esc_html__( 'hollow rectangle', 'simple-days' ),
        ),
      ));

      $wp_customize->add_setting( 'simple_days_profile_social_link_size',array(
        'default'    => '',
        'sanitize_callback' => 'sanitize_text_field',
      ));
      $wp_customize->add_control( 'simple_days_profile_social_link_size',array(
        'label'   => esc_html__( 'Icon Size', 'simple-days'),
        'section' => 'simple_days_profile_setting',
        'type'     => 'radio',
        'choices'  => array(
          'icon_small' => esc_html__( 'small', 'simple-days' ),
          '' => esc_html__( 'medium', 'simple-days' ),
          'icon_large' => esc_html__( 'large', 'simple-days' ),
          'icon_xlarge' => esc_html__( 'extra large', 'simple-days' ),
        ),
      ));

  $wp_customize->add_setting( 'simple_days_profile_social_icon_color',array(
    'default'    => false,
    'sanitize_callback' => 'sanitize_text_field',
  ));
  $wp_customize->add_control( 'simple_days_profile_social_icon_color',array(
    'label'   => esc_html__( 'Enable', 'simple-days'),
    'description' => esc_html__('Dark color', 'simple-days'),
    'section' => 'simple_days_profile_setting',
    'type' => 'checkbox',
  ));




      $i = 1;
      while($i <= 5){
        $wp_customize->add_setting( 'simple_days_profile_social_icon_'.$i,array(
          'default'       => 'none',
          'sanitize_callback' => 'simple_days_sns_name_sanitize',
        ));
        $wp_customize->add_control('simple_days_profile_social_icon_'.$i,array(
          
          'label'   => sprintf(esc_html__( 'Social Icon #%s', 'simple-days'),$i),
          'section' => 'simple_days_profile_setting',
          'type'    => 'select',
          'choices' => $sns_link_name,
          'priority'  => $i+100,
        ));
        $i++;
      }




      $wp_customize->add_section('simple_days_toc_setting',array(
        'title' => esc_html__('Table of contents', 'simple-days'),
        'panel' => 'simple_days_setting',
      ));

  $wp_customize->add_setting('toc_setting',array('sanitize_callback' => 'absint',));
  $wp_customize->add_control('toc_setting',array(
    'section' => 'simple_days_toc_setting',
    'type' => 'hidden'
  ));
  $wp_customize->selective_refresh->add_partial( 'toc_setting', array(
         'selector' => '.simple_days_toc',
  ));


      $wp_customize->add_setting( 'simple_days_toc',array(
        'default'    => false,
        'sanitize_callback' => 'sanitize_text_field',
      ));
      $wp_customize->add_control( 'simple_days_toc',array(
        'label'   => esc_html__( 'Enable', 'simple-days'),
        'description' => esc_html__('insert table of contents', 'simple-days'),
        'section' => 'simple_days_toc_setting',
        'type' => 'checkbox',
      ));
      $wp_customize->add_setting( 'simple_days_toc_hide',array(
        'default'    => false,
        'sanitize_callback' => 'sanitize_text_field',
      ));
      $wp_customize->add_control( 'simple_days_toc_hide',array(
        'label'   => esc_html__( 'Initially hide table of contents', 'simple-days'),
        'section' => 'simple_days_toc_setting',
        'type' => 'checkbox',
      ));
      $wp_customize->add_setting( 'simple_days_toc_dc',array(
        'default'    => '3',
        'sanitize_callback' => 'simple_days_sanitize_select',
      ));
      $wp_customize->add_control( 'simple_days_toc_dc',array(
        'label'   => esc_html__( 'lower limit the heading which toc is displayed', 'simple-days'),
        'section' => 'simple_days_toc_setting',
        'type' => 'select',
        'choices' => array(
             '2' => '2',
             '3' => '3',
             '4' => '4',
             '5' => '5',
             '6' => '6',
             '7' => '7',
             '8' => '8',
             '9' => '9',
            '10' => '10',
        ),
      ));
      $wp_customize->add_setting( 'simple_days_toc_post',array(
        'default'    => true,
        'sanitize_callback' => 'sanitize_text_field',
      ));
      $wp_customize->add_control( 'simple_days_toc_post',array(
        'label'   => esc_html__( 'Automatically display toc in post', 'simple-days'),
        'section' => 'simple_days_toc_setting',
        'type' => 'checkbox',
      ));
      $wp_customize->add_setting( 'simple_days_toc_page',array(
        'default'    => true,
        'sanitize_callback' => 'sanitize_text_field',
      ));
      $wp_customize->add_control( 'simple_days_toc_page',array(
        'label'   => esc_html__( 'Automatically display toc in page', 'simple-days'),
        'section' => 'simple_days_toc_setting',
        'type' => 'checkbox',
      ));
      $wp_customize->add_setting( 'simple_days_toc_dp',array(
        'default'    => '0',
        'sanitize_callback' => 'simple_days_sanitize_select',
      ));
      $wp_customize->add_control( 'simple_days_toc_dp',array(
        'label'   => esc_html__( 'display position', 'simple-days'),
        'section' => 'simple_days_toc_setting',
        'type' => 'select',
        'choices' => array(
             '0' => esc_html__('Before the first heading', 'simple-days'),
             '1' => esc_html__('After the first heading', 'simple-days'),
             '2' => esc_html__('Top', 'simple-days'),
        ),
      ));
      $wp_customize->add_setting( 'simple_days_toc_hierarchical',array(
        'default'    => false,
        'sanitize_callback' => 'sanitize_text_field',
      ));
      $wp_customize->add_control( 'simple_days_toc_hierarchical',array(
        'label'   => esc_html__( 'hierarchical view', 'simple-days'),
        'section' => 'simple_days_toc_setting',
        'type' => 'checkbox',
      ));
      $wp_customize->add_setting( 'simple_days_toc_numerical',array(
        'default'    => true,
        'sanitize_callback' => 'sanitize_text_field',
      ));
      $wp_customize->add_control( 'simple_days_toc_numerical',array(
        'label'   => esc_html__( 'numerical display', 'simple-days'),
        'section' => 'simple_days_toc_setting',
        'type' => 'checkbox',
      ));
      $wp_customize->add_setting( 'simple_days_toc_widget',array(
        'default'    => false,
        'sanitize_callback' => 'sanitize_text_field',
      ));
      $wp_customize->add_control( 'simple_days_toc_widget',array(
        'label'   => esc_html__( 'Enable', 'simple-days'),
        'description' => esc_html__('Add Widgets TOC', 'simple-days'),
        'section' => 'simple_days_toc_setting',
        'type' => 'checkbox',
      ));
      $wp_customize->add_setting( 'simple_days_toc_widget_sticky',array(
        'default'    => false,
        'sanitize_callback' => 'sanitize_text_field',
      ));
      $wp_customize->add_control( 'simple_days_toc_widget_sticky',array(
        'label'   => esc_html__( 'Enable', 'simple-days'),
        'description' => esc_html__('Sticky TOC of SideBar Widgets', 'simple-days'),
        'section' => 'simple_days_toc_setting',
        'type' => 'checkbox',
      ));

      $wp_customize->add_section('simple_days_blog_card_setting',array(
        'title' => esc_html__('Blog Card', 'simple-days'),
        'panel' => 'simple_days_setting',
      ));
      $wp_customize->add_setting( 'simple_days_blog_card_internal',array(
        'default'    => false,
        'sanitize_callback' => 'sanitize_text_field',
      ));
      $wp_customize->add_control( 'simple_days_blog_card_internal',array(
        'label'   => esc_html__( 'Enable', 'simple-days'),
        'description' => esc_html__('Blog card(internal site)', 'simple-days'),
        'section' => 'simple_days_blog_card_setting',
        'type' => 'checkbox',
      ));
      $wp_customize->add_setting( 'simple_days_blog_card_external',array(
        'default'    => false,
        'sanitize_callback' => 'sanitize_text_field',
      ));
      $wp_customize->add_control( 'simple_days_blog_card_external',array(
        'label'   => esc_html__( 'Enable', 'simple-days'),
        'description' => esc_html__('Blog card(external site)', 'simple-days'),
        'section' => 'simple_days_blog_card_setting',
        'type' => 'checkbox',
      ));


      $wp_customize->add_section('simple_days_amp_setting',array(
        'title' => esc_html__('AMP(beta Ver.)', 'simple-days'),
        'panel' => 'simple_days_setting',
      ));


      $wp_customize->add_setting( 'simple_days_amp',array(
        'default'    => false,
        'sanitize_callback' => 'sanitize_text_field',
      ));
      $wp_customize->add_control( 'simple_days_amp',array(
        'label'   => esc_html__( 'Enable', 'simple-days'),
        'description' => esc_html__('Accelerated Mobile Pages(AMP)', 'simple-days'),
        'section' => 'simple_days_amp_setting',
        'type' => 'checkbox',
      ));


      $wp_customize->add_setting( 'simple_days_amp_analytics',array(
        'default'           => '',
        'sanitize_callback' => 'wp_strip_all_tags',
      ));
      $wp_customize->add_control('simple_days_amp_analytics',array(
        'label'   => esc_html__( 'Google Analytics AMP account', 'simple-days'),
        'description' => esc_html__('e.g.&nbsp;', 'simple-days').esc_html('UA-XXXXXX-Y'),
        'section' => 'simple_days_amp_setting',
        'type'    => 'text',
      ));



      $wp_customize->add_setting( 'simple_days_amp_logo_img',array(
        'default'    => esc_url(get_template_directory_uri() .'/assets/images/amp-logo.png'),
        'sanitize_callback' => 'simple_days_sanitize_image_file',
      ));
      $wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'simple_days_amp_logo_img', array(
        'label' => esc_html__( 'AMP Logo Image', 'simple-days'),
        'description' => __( 'AMP Logo use this image.', 'simple-days').'<br />'.__( 'For more information', 'simple-days').' <a href="'.esc_url('https://developers.google.com/search/docs/data-types/article#amp').'" target="_blank">'.__( 'click here' , 'simple-days').'</a>',
        'section' => 'simple_days_amp_setting',
      )));




  $wp_customize->add_section('simple_days_google_analytics_setteing',array(
    'title' => esc_html__('Google Analytics', 'simple-days'),
    'panel' => 'simple_days_setting',
  ));

  $wp_customize->add_setting( 'simple_days_ga_analytics', array(
    'default'           => 'false',
    'sanitize_callback' => 'simple_days_sanitize_radio',
    )
  );
  $wp_customize->add_control( 'simple_days_ga_analytics', array(
    'label'    => esc_html__( 'Google Analytics', 'simple-days' ),
    'section'  => 'simple_days_google_analytics_setteing',
    'type'     => 'radio',
    'choices'  => array(
      'false' => esc_html__( 'Disable', 'simple-days' ),
      '1' => esc_html__( 'ga.js', 'simple-days' ),
      '2' => esc_html__( 'gtag.js', 'simple-days' ),
    ),
  ));

  $wp_customize->add_setting( 'simple_days_ga_analytics_id',array(
        'default'           => '',
        'sanitize_callback' => 'wp_strip_all_tags',
  ));
  $wp_customize->add_control('simple_days_ga_analytics_id',array(
        'label'   => esc_html__( 'Google Analytics account', 'simple-days'),
        'description' => esc_html__('e.g.&nbsp;', 'simple-days').esc_html('UA-XXXXXX-Y'),
        'section' => 'simple_days_google_analytics_setteing',
        'type'    => 'text',
  ));

  $wp_customize->add_setting( 'simple_days_google_site_verification',array(
        'default'           => '',
        'sanitize_callback' => 'wp_strip_all_tags',
  ));
  $wp_customize->add_control('simple_days_google_site_verification',array(
        'label'   => esc_html__( 'Google Site Verification', 'simple-days'),
        'description' => esc_html__('e.g.&nbsp;', 'simple-days').esc_html('1234567890AbCdeFghIjKLMnoPQrstuVWXYz'),
        'section' => 'simple_days_google_analytics_setteing',
        'type'    => 'text',
  ));











  // Add Settings and Controls for Google AD.
  $wp_customize->add_section('simple_days_google_ad_setteing',array(
    'title' => esc_html__('Google AdSense', 'simple-days'),
    'panel' => 'simple_days_setting',
  ));

  $wp_customize->add_setting( 'simple_days_google_ad',array(
    'default'    => true,
    'sanitize_callback' => 'sanitize_text_field',
  ));
  $wp_customize->add_control( 'simple_days_google_ad',array(
    'label'   => esc_html__( 'Enable', 'simple-days'),
    'description' => esc_html__('Add Widgets Google AdSense', 'simple-days'),
    'section' => 'simple_days_google_ad_setteing',
    'type' => 'checkbox',
  ));
  $wp_customize->add_setting( 'simple_days_google_ad_publisher_id',array(
    'default'           => '',
    'sanitize_callback' => 'wp_strip_all_tags',
  ));
  $wp_customize->add_control('simple_days_google_ad_publisher_id',array(
    'label'   => esc_html__( 'Your publisher ID(data-ad-client):', 'simple-days'),
    'description' => esc_html__('e.g.&nbsp;', 'simple-days').esc_html('ca-pub-1234567890'),
    'section' => 'simple_days_google_ad_setteing',
    'type'    => 'text',
  ));
  $wp_customize->add_setting( 'simple_days_google_ad_labeling',array(
    'default'    => '0',
    'sanitize_callback' => 'sanitize_text_field',
  ));
  $wp_customize->add_control( 'simple_days_google_ad_labeling',array(
    'label'   => esc_html__( 'Labeling ads', 'simple-days'),
    'section' => 'simple_days_google_ad_setteing',
    'type'     => 'radio',
    'choices'  => array(
      '0' => esc_html__( 'Hide', 'simple-days' ),
      '1' => esc_html__( 'Advertisements', 'simple-days' ),
      '2' => esc_html__( 'Sponsored Links', 'simple-days' ),
    ),
  ));




  // Add Settings and Controls for OGP.
  $wp_customize->add_section('simple_days_ogp_setteing',array(
    'title' => esc_html__('OGP', 'simple-days'),
    'panel' => 'simple_days_setting',
  ));

  $wp_customize->add_setting( 'simple_days_ogp',array(
        'default'    => false,
        'sanitize_callback' => 'sanitize_text_field',
  ));
  $wp_customize->add_control( 'simple_days_ogp',array(
        'label'   => esc_html__( 'Enable', 'simple-days'),
        'description' => esc_html__('add metadata for Open Graph protocol(OGP)', 'simple-days'),
        'section' => 'simple_days_ogp_setteing',
        'type' => 'checkbox',
  ));

  $wp_customize->add_setting( 'simple_days_ogp_logo_img',array(
        'default'    => esc_url(get_template_directory_uri() .'/assets/images/ogp.jpg'),
        'sanitize_callback' => 'simple_days_sanitize_image_file',
  ));
  $wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'simple_days_ogp_logo_img', array(
        'label' => esc_html__( 'OGP Image', 'simple-days'),
        'description' => esc_html__( 'If no thumbnail or home page then use this image.', 'simple-days'),
        'section' => 'simple_days_ogp_setteing',
  )));


  $wp_customize->add_setting( 'simple_days_twitter_card', array(
    'default'           => 'false',
    'sanitize_callback' => 'simple_days_sanitize_radio',
    )
  );
  $wp_customize->add_control( 'simple_days_twitter_card', array(
    'label'    => esc_html__( 'Twitter Card', 'simple-days' ),
    'section'  => 'simple_days_ogp_setteing',
    'type'     => 'radio',
    'choices'  => array(
      'false' => esc_html__( 'Disable', 'simple-days' ),
      'summary' => esc_html__( 'Summary Card', 'simple-days' ),
      'summary_large_image' => esc_html__( 'Summary Card with Large Image', 'simple-days' ),
    ),
  ));





  // Add Settings and Controls for Sitemap.
  $wp_customize->add_section('simple_days_sitemap_setteing',array(
    'title' => esc_html__('Site map', 'simple-days'),
    'panel' => 'simple_days_setting',
  ));


  $wp_customize->add_setting( 'simple_days_sitemap_page',array(
    'default'    => false,
    'sanitize_callback' => 'sanitize_text_field',
  ));
  $wp_customize->add_control( 'simple_days_sitemap_page',array(
    'label'   => esc_html__( 'Enable', 'simple-days'),
    'description' => esc_html__('Display the site map at the page.', 'simple-days'),
    'section' => 'simple_days_sitemap_setteing',
    'type' => 'checkbox',
  ));
  $wp_customize->add_setting( 'simple_days_sitemap_page_post_name',array(
        'default'           => '',
        'sanitize_callback' => 'wp_strip_all_tags',
  ));
  $wp_customize->add_control('simple_days_sitemap_page_post_name',array(
        'label'   => esc_html__( 'Page slug to be display at the page.', 'simple-days'),
        'description' => esc_html__('e.g.&nbsp;', 'simple-days').esc_html('sitemap'),
        'section' => 'simple_days_sitemap_setteing',
        'type'    => 'text',
  ));



  $wp_customize->add_setting( 'simple_days_sitemap_footer',array(
    'default'    => false,
    'sanitize_callback' => 'sanitize_text_field',
  ));
  $wp_customize->add_control( 'simple_days_sitemap_footer',array(
    'label'   => esc_html__( 'Enable', 'simple-days'),
    'description' => esc_html__('Display the site map link at footer area', 'simple-days'),
    'section' => 'simple_days_sitemap_setteing',
    'type' => 'checkbox',
  ));



  // Add Settings and Controls for Option.
  $wp_customize->add_section('simple_days_script_css',array(
    'title' => esc_html__('JavaScript and CSS', 'simple-days'),
    'panel' => 'simple_days_setting',
  ));

  $wp_customize->add_setting( 'simple_days_lightbox',array(
    'default'    => 'false',
    'sanitize_callback' => 'sanitize_text_field',
  ));
  $wp_customize->add_control( 'simple_days_lightbox',array(
    'label'   => esc_html__( 'Lightbox', 'simple-days'),
    'section' => 'simple_days_script_css',
    'type'     => 'radio',
    'choices'  => array(
      'false' => esc_html__( 'Disable', 'simple-days' ),
      'lity' => esc_html__( 'Lity', 'simple-days' ),
    ),
  ));



  $wp_customize->add_setting( 'simple_days_highlight',array(
    'default'    => false,
    'sanitize_callback' => 'sanitize_text_field',
  ));
  $wp_customize->add_control( 'simple_days_highlight',array(
    'label'   => esc_html__( 'Enable', 'simple-days'),
    'description' => esc_html__('use highlight.js', 'simple-days'),
    'section' => 'simple_days_script_css',
    'type' => 'checkbox',
  ));

  $wp_customize->add_setting( 'simple_days_highlight_styles',array(
    'default'       => 'default',
    'sanitize_callback' => 'simple_days_sanitize_select',
  ));

      $highlight_styles = array(
        'default'                 => 'default',
        'agate'                   => 'agate',
        'androidstudio'                 => 'androidstudio',
        'arduino-light'                   => 'arduino-light',
        'arta'                 => 'arta',
        'ascetic'                   => 'ascetic',
        'atelier-cave-dark'                 => 'atelier-cave-dark',
        'atelier-cave-light'                   => 'atelier-cave-light',
        'atelier-dune-dark'                 => 'atelier-dune-dark',
        'atelier-dune-light'                   => 'atelier-dune-light',
        'atelier-estuary-dark'                 => 'atelier-estuary-dark',
        'atelier-estuary-light'                   => 'atelier-estuary-light',
        'atelier-forest-dark'                 => 'atelier-forest-dark',
        'atelier-forest-light'                   => 'atelier-forest-light',
        'atelier-heath-dark'                 => 'atelier-heath-dark',
        'atelier-heath-light'                   => 'atelier-heath-light',
        'atelier-lakeside-dark'                 => 'atelier-lakeside-dark',
        'atelier-lakeside-light'                   => 'atelier-lakeside-light',
        'atelier-plateau-dark'                 => 'atelier-plateau-dark',
        'atelier-plateau-light'                   => 'atelier-plateau-light',
        'atelier-savanna-dark'                 => 'atelier-savanna-dark',
        'atelier-savanna-light'                   => 'atelier-savanna-light',
        'atelier-seaside-dark'                 => 'atelier-seaside-dark',
        'atelier-seaside-light'                   => 'atelier-seaside-light',
        'atelier-sulphurpool-dark'                 => 'atelier-sulphurpool-dark',
        'atelier-sulphurpool-light'                   => 'atelier-sulphurpool-light',
        'atom-one-dark'                 => 'atom-one-dark',
        'atom-one-light'                   => 'atom-one-light',
        'brown-paper'                 => 'brown-paper',
        'codepen-embed'                   => 'codepen-embed',
        'color-brewer'                 => 'color-brewer',
        'darcula'                   => 'darcula',
        'dark'                 => 'dark',
        'darkula'                   => 'darkula',
        'docco'                 => 'docco',
        'dracula'                   => 'dracula',
        'far'                 => 'far',
        'foundation'                   => 'foundation',
        'github'                 => 'github',
        'github-gist'                   => 'github-gist',
        'googlecode'                 => 'googlecode',
        'grayscale'                   => 'grayscale',
        'gruvbox-dark'                 => 'gruvbox-dark',
        'gruvbox-light'                   => 'gruvbox-light',
        'hopscotch'                 => 'hopscotch',
        'hybrid'                   => 'hybrid',
        'idea'                 => 'idea',
        'ir-black'                   => 'ir-black',
        'kimbie.dark'                 => 'kimbie.dark',
        'kimbie.light'                   => 'kimbie.light',
        'magula'                   => 'magula',
        'mono-blue'                 => 'mono-blue',
        'monokai'                   => 'monokai',
        'monokai-sublime'                 => 'monokai-sublime',
        'obsidian'                   => 'obsidian',
        'ocean'                 => 'ocean',
        'paraiso-dark'                   => 'paraiso-dark',
        'paraiso-light'                 => 'paraiso-light',
        'pojoaque'                   => 'pojoaque',
        'purebasic'                   => 'purebasic',
        'qtcreator_dark'                 => 'qtcreator_dark',
        'qtcreator_light'                   => 'qtcreator_light',
        'railscasts'                 => 'railscasts',
        'rainbow'                   => 'rainbow',
        'routeros'                 => 'routeros',
        'school-book'                   => 'school-book',
        'solarized-dark'                 => 'solarized-dark',
        'solarized-light'                   => 'solarized-light',
        'sunburst'                   => 'sunburst',
        'tomorrow'                 => 'tomorrow',
        'tomorrow-night'                   => 'tomorrow-night',
        'tomorrow-night-blue'                 => 'tomorrow-night-blue',
        'tomorrow-night-bright'                   => 'tomorrow-night-bright',
        'tomorrow-night-eighties'                 => 'tomorrow-night-eighties',
        'vs'                   => 'vs',
        'vs2015'                 => 'vs2015',
        'xcode'                   => 'xcode',
        'xt256'                   => 'xt256',
        'zenburn'                 => 'zenburn',
      );

  $wp_customize->add_control('simple_days_highlight_styles',array(
    'label'   => esc_html__( 'Style of highlight.js', 'simple-days'),
    'section' => 'simple_days_script_css',
    'type'    => 'select',
    'choices' => $highlight_styles,
  ));

  $wp_customize->add_setting( 'simple_days_fontawesome',array(
    'default'    => false,
    'sanitize_callback' => 'sanitize_text_field',
  ));
  $wp_customize->add_control( 'simple_days_fontawesome',array(
    'label'   => esc_html__( 'Enable', 'simple-days'),
    'description' => esc_html__('use CDN FontAwesome 4', 'simple-days'),
    'section' => 'simple_days_script_css',
    'type' => 'checkbox',
  ));



  // Add Settings and Controls for Option.
  $wp_customize->add_section('simple_days_option',array(
    'title' => esc_html__('Option', 'simple-days'),
    'panel' => 'simple_days_setting',
  ));








  $wp_customize->add_setting( 'simple_days_404_img',array(
        'default'    => esc_url(get_template_directory_uri() .'/assets/images/404.jpg'),
        'sanitize_callback' => 'simple_days_sanitize_image_file',
  ));
  $wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'simple_days_404_img', array(
        'label' => esc_html__( '404 Image', 'simple-days'),
        'description' => esc_html__( '404 page use this image.', 'simple-days'),
        'section' => 'simple_days_option',
  )));



      
      $wp_customize->add_setting('copyright',array('sanitize_callback' => 'absint',));
      $wp_customize->add_control('copyright',array(
        'section' => 'simple_days_option',
        'type' => 'hidden'
      ));
      $wp_customize->selective_refresh->add_partial( 'copyright', array(
         'selector' => '.credit',
      ));

      $allowed_html = array(
        'a' => array( 'href' => array (), 'onclick' => array (), 'target' => array(), 'title' => array() ),
        'br' => array(),
        'strong' => array(),
        'b' => array(),
      );
      $copyright = '&copy; ';
      $wp_customize->add_setting( 'simple_days_copyright_text',array(
        'default'           => $copyright.esc_html( date_i18n(__('Y','simple-days'))).' <a href="'. esc_url( home_url() ).'">'. get_bloginfo('name').'</a>.',
        'sanitize_callback' => 'wp_kses_post',
      ));
      $wp_customize->add_control('simple_days_copyright_text',array(
        'label'   => esc_html__( 'Copyright', 'simple-days'),
        'section' => 'simple_days_option',
        'type'    => 'textarea',
      ));



      //Link Color
      $wp_customize->add_setting( 'simple_days_background_color',array(
            'default'           => define("simple_days_background_color", ""),
            'sanitize_callback' => 'sanitize_hex_color',
      ));
      $wp_customize->add_control( new WP_Customize_Color_Control($wp_customize,
         'simple_days_background_color',array(
            'label'      => esc_html__( 'Background Color', 'simple-days' ),
            'section'    => 'colors',
            'description' => esc_html__('default&#58;', 'simple-days').esc_html('&#35;fff'),
      )));
      //Link Color
      $wp_customize->add_setting( 'link_textcolor',array(
            'default'           => define("link_textcolor", ""),
            'sanitize_callback' => 'sanitize_hex_color',
      ));
      $wp_customize->add_control( new WP_Customize_Color_Control($wp_customize,
         'link_textcolor',array(
            'label'      => esc_html__( 'Link Color', 'simple-days' ),
            'section'    => 'colors',
            'description' => esc_html__('default&#58;', 'simple-days').esc_html('&#35;07a'),
      )));
      //Link Hover Color
      $wp_customize->add_setting( 'link_hover_color',array(
            'default'           => define("link_hover_color", ""),
            'sanitize_callback' => 'sanitize_hex_color',
      ));
      $wp_customize->add_control( new WP_Customize_Color_Control(
         $wp_customize,'link_hover_color',array(
            'label'      => esc_html__( 'Link Hover Color', 'simple-days' ),
            'section'    => 'colors',
            'description' => esc_html__('default&#58;', 'simple-days').esc_html('&#35;d42'),
      )));
      //Blog Title Color
      $wp_customize->add_setting( 'blog_name',array(
            'default'           => define("blog_name", ""),
            'sanitize_callback' => 'sanitize_hex_color',
      ));
      $wp_customize->add_control( new WP_Customize_Color_Control(
         $wp_customize,'blog_name',array(
            'label'      => esc_html__( 'Site Title', 'simple-days' ),
            'section'    => 'colors',
            'description' => esc_html__('default&#58;', 'simple-days').esc_html('&#35;07a'),
      )));



      
      if ( isset( $wp_customize->selective_refresh ) ) {
        $wp_customize->selective_refresh->add_partial( 'blogname', array(
        'selector' => '.site_title',
        'render_callback' => 'simple_days_customize_partial_blogname',
        ) );
      }
      $wp_customize->get_setting( 'blogname' )->transport = 'postMessage';

   }

   function simple_days_customize_partial_blogname() {
	    bloginfo( 'name' );
   }

   public static function header_output() {

      if ( !is_amp() ){ ?>
      <!--Customizer CSS-->
      <style type="text/css">
           <?php self::generate_css('body', 'background-color', 'simple_days_background_color'); ?>
           <?php self::generate_css('a', 'color', 'link_textcolor'); ?>
           <?php self::generate_css('a:hoverhover:not(.non_hover)', 'color', 'link_hover_color'); ?>
           <?php self::generate_css('.site_title a', 'color', 'blog_name'); ?>
           <?php $header_image = get_header_image();
           if (!empty( $header_image )){ ?>
             #site_header {
                 background-image: url(<?php header_image(); ?>);
                 background-size: cover;
             }
           <?php } ?>
           <?php if(get_theme_mod( 'simple_days_sidebar_layout','3') == 1){
                    echo ' .sidebar{-webkit-box-ordinal-group:1;-ms-flex-order:1;-webkit-order:1;order:1;margin: 0 30px 0 0;} ';
                 }
           ?>
      </style>
      <!--/Customizer CSS-->
<?php }
   }

    /**
     * <head> 内に出力する CSS を作成します。
     * $mod_name 設定が未定義の場合は、何も出力しません。
     *
     * @uses get_theme_mod()
     * @param string $selector CSSセレクタ。
     * @param string $style 変更する CSS *プロパティ* 名。
     * @param string $mod_name 'theme_mod' 設定の名前。
     * @param string $prefix （任意）CSS プロパティの前に出力する内容。
     * @param string $postfix （任意）CSS プロパティの後に出力する内容。
     * @param bool $echo （任意）出力するか否か (デフォルト：true)。
     * @return string セレクタとプロパティからなる1行の CSS を返します。
     * @since MyTheme 1.0
     */
    public static function generate_css( $selector, $style, $mod_name, $prefix='', $postfix='', $echo=true ) {
      $return = '';
      $mod = get_theme_mod($mod_name);
      if ( ! empty( $mod ) ) {
         $return = sprintf('%s { %s:%s; }',
            $selector,
            $style,
            $prefix.$mod.$postfix
         );
         if ( $echo ) {
            echo esc_attr($return);
         }
      }
      return $return;
    }
}

// Setup the Theme Customizer settings and controls...
add_action( 'customize_register' , array( 'Simple_Days_Customize' , 'register' ) );

// Output custom CSS to live site
add_action( 'wp_head' , array( 'Simple_Days_Customize' , 'header_output' ) );
